@@ -196,6 +196,8 @@ def up() -> None:
 @up.command()
 @click.argument("directory")
 @click.option("--url", default=_get_url, help="Base URL of Scotty")
+@click.option("--issue", help="Associated issue ticket name")
+@click.option("--tracker", default="JIRA", help="Issue tracker name")
 @click.option(
     "-t",
     "--tag",
@@ -203,7 +205,9 @@ def up() -> None:
     multiple=True,
     help="Tag to be associated with the beam. Can be specified multiple times",
 )
-def local(directory: str, url: str, tags: typing.List[str]) -> None:
+def local(
+    directory: str, url: str, tags: typing.List[str], issue: str, tracker: str
+) -> None:
     logging.basicConfig(
         format="%(name)s:%(levelname)s:%(message)s", level=logging.DEBUG
     )
@@ -211,7 +215,9 @@ def local(directory: str, url: str, tags: typing.List[str]) -> None:
     scotty = Scotty(url)
 
     click.echo("Beaming up {}".format(directory))
-    beam_id = scotty.beam_up(directory, tags=tags)
+    beam_id = scotty.beam_up(
+        directory, tags=tags, associated_issue=issue, tracker_name=tracker
+    )
     click.echo("Successfully beamed beam #{}".format(beam_id))
 
 
